==> wawa-service-common-0.0.29-sources.jar: cn/com/wawa/common/constants/BizConstants.java <==
package cn.com.wawa.common.constants;

/**
 * Created by gyf .
 * 2017/10/28 .
 */
public class BizConstants {

    /**
     * 用户抓抓号
     */
    public static final Long USER_FIX_ID = 1241325363L;

    private BizConstants() {
    }

    /**
     * 摄像头1号前缀
     */
    public static final String CAMERA1_PREFIX = "AAA%s";

    /**
     * 摄像头2号前缀
     */
    public static final String CAMERA2_PREFIX = "BBB%s";

    /**
     * 邮费
     */
    public static final long POSTAGE = 50L;

    /**
     * 虚拟商品wind_order中ext中的领取备注
     */
    public static final String VIRTUAL_GOODS_RECEIVE_REMARK = "virtualGoodsRemark";

    /**
     * 虚拟商品wind_order中ext中的后台标记
     */
    public static final String VIRTUAL_GOODS_RECEIVE_RECORD = "virtualGoodsRecord";

    /**
     * 虚拟商品wind_order中返回对象中ext中的领取规则
     */
    public static final String VIRTUAL_GOODS_RECEIVE_RULE = "virtualGoodsRule";

    /**
     * wawa表中详情字段的详情图片地址
     */
    public static final String WAWA_DETAIL_PICS = "detailPics";

    /**
     * wawa表中详情字段的详情描述
     */
    public static final String WAWA_DETAIL_DESCR = "detailDescr";

    /**
     * wawa表中详情字段的娃娃名称
     */
    public static final String WAWA_DETAIL_WAWA_NAME = "detailWawaName";


    /**
     * 业务服务器作为长连接客户端的clientId
     */
    public static final String SERVICE_CLIENT_ID = "service_client_%s";

    /**
     * 报警消息文案
     */
    public static final String CATCHER_ALARM_TEXT = "%s娃娃机报警:%s:%s";//第一位是catcher_name,第二位报警内容,第三位报警code

    /**
     * h5默认头像地址
     */
    public static final String[] DEFAULT_AVATAR_URL = {
            "http://yun.tuipink.com/wawa/images/daubhqzx3i.jpg",
            "http://yun.tuipink.com/wawa/images/dm0xspcr2q.jpg",
            "http://yun.tuipink.com/wawa/images/qsesesxoqn.jpg",
            "http://yun.tuipink.com/wawa/images/ypls1en9o9.jpg",
            "http://yun.tuipink.com/wawa/images/cerh5sywqg.jpg",
            "http://yun.tuipink.com/wawa/images/5sbwyvkguc.jpg",
            "http://yun.tuipink.com/wawa/images/fr16y182yg.jpg",
            "http://yun.tuipink.com/wawa/images/euy35t0v6s.jpg"
            //"http://yun.tuipink.com/wawaji/h5/images/common/avatar.png",
    };

}

==> wawa-service-common-0.0.29-20180402.040137-5-sources.jar: cn/com/wawa/common/constants/BizConstants.java <==
package cn.com.wawa.common.constants;

/**
 * Created by gyf .
 * 2017/10/28 .
 */
public class BizConstants {

    /**
     * 用户抓抓号
     */
    public static final Long USER_FIX_ID = 1241325363L;

    private BizConstants() {
    }

    /**
     * 摄像头1号前缀
     */
    public static final String CAMERA1_PREFIX = "AAA%s";

    /**
     * 摄像头2号前缀
     */
    public static final String CAMERA2_PREFIX = "BBB%s";

    /**
     * 邮费
     */
    public static final long POSTAGE = 50L;

    /**
     * 虚拟商品wind_order中ext中的领取备注
     */
    public static final String VIRTUAL_GOODS_RECEIVE_REMARK = "virtualGoodsRemark";

    /**
     * 虚拟商品wind_order中ext中的后台标记
     */
    public static final String VIRTUAL_GOODS_RECEIVE_RECORD = "virtualGoodsRecord";

    /**
     * 虚拟商品wind_order中返回对象中ext中的领取规则
     */
    public static final String VIRTUAL_GOODS_RECEIVE_RULE = "virtualGoodsRule";

    /**
     * wawa表中详情字段的详情图片地址
     */
    public static final String WAWA_DETAIL_PICS = "detailPics";

    /**
     * wawa表中详情字段的详情描述
     */
    public static final String WAWA_DETAIL_DESCR = "detailDescr";

    /**
     * wawa表中详情字段的娃娃名称
     */
    public static final String WAWA_DETAIL_WAWA_NAME = "detailWawaName";


    /**
     * 业务服务器作为长连接客户端的clientId
     */
    public static final String SERVICE_CLIENT_ID = "service_client_%s";

    /**
     * 报警消息文案
     */
    public static final String CATCHER_ALARM_TEXT = "%s娃娃机报警:%s:%s";//第一位是catcher_name,第二位报警内容,第三位报警code

    /**
     * h5默认头像地址
     */
    public static final String DEFAULT_AVATAR_URL = "http://yun.tuipink.com/wawaji/h5/images/common/avatar.png";

}
